@@ -225,6 +225,14 @@ p, li { white-space: pre-wrap; }
         <source>Qt Version:</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Make a Donation!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Donate using PayPal, Ko-Fi or Cryptocurrencies.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>DialogMultipageEditor</name>
@@ -293,6 +301,10 @@ p, li { white-space: pre-wrap; }
         <source>F1</source>
         <translation>F1</translation>
     </message>
+    <message>
+        <source>In order to perform the conversion of &lt;b&gt;PDF&lt;/b&gt; files to images, &lt;b&gt;Ghostscript for Windows (%1)&lt;/b&gt; must be installed on your system.&lt;br&gt;&lt;br&gt;                               Please install the correct version of Ghostscript.&lt;br&gt;                               Click on the &lt;b&gt;Help&lt;/b&gt; button for more details.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>DialogOptions</name>
@@ -796,11 +808,6 @@ p, li { white-space: pre-wrap; }
         <source>F1</source>
         <translation>F1</translation>
     </message>
-    <message>
-        <source>Donate via Paypal</source>
-        <translatorcomment>Menü ögeleri için Tümce düzeni tercih edildi</translatorcomment>
-        <translation>Paypal ile bağış yap</translation>
-    </message>
     <message>
         <source>Rotate and flip</source>
         <translation>Döndür ve çevir</translation>
@@ -854,11 +861,6 @@ p, li { white-space: pre-wrap; }
         <translatorcomment>Dosyaları sıralı şekilde numaralandırırken kullanılıyor</translatorcomment>
         <translation>&amp;İlerlemeli Numara</translation>
     </message>
-    <message>
-        <source>&amp;Donate via Paypal</source>
-        <translatorcomment>Menü ögeleri için Tümce düzeni tercih edildi</translatorcomment>
-        <translation>&amp;Paypal ile bağış yap</translation>
-    </message>
     <message>
         <source>&amp;Report bug...</source>
         <translation>&amp;Hata raporla...</translation>
@@ -907,6 +909,14 @@ p, li { white-space: pre-wrap; }
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:700;&quot;&gt;Link Aspect Ratio with Selected Image&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Automatically adjusts the aspect ratio values when you enter a value in the &lt;span style=&quot; font-weight:700;&quot;&gt;Width/Height&lt;/span&gt; fields.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>&amp;Donate!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Donate via Paypal, Ko-Fi, Cryptocurrencies</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>MainWindowImpl</name>
