@@ -2,7 +2,7 @@
 * This file is part of Converseen, an open-source batch image converter
 * and resizer.
 *
-* (C) Francesco Mondello 2009 - 2023
+* (C) Francesco Mondello 2009 - 2024
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -47,7 +47,15 @@ QTranslator *Translator::translation()
     QTranslator *transl = new QTranslator;
     QString translationFile = QString("%1/%2").arg(m_loc).arg(loadCurrentTranslationName());
     //QString translationFileQt = QLibraryInfo::location(QLibraryInfo::TranslationsPath) + "qt_" + QLocale::system().name();
-    transl->load(translationFile);
+
+    QFileInfo fi(translationFile);
+
+    if (fi.exists()) {
+        transl->load(translationFile);
+        return transl;
+    }
+    else
+        return NULL;
 
     //
     /*transl->load("qt_" + QLocale::system().name(),
@@ -55,7 +63,7 @@ QTranslator *Translator::translation()
 
     //qDebug() << "Locations " << QStandardPaths::standardLocations(QStandardPaths::AppLocalDataLocation);
 
-    return(transl);
+
 }
 
 QString Translator::loadCurrentTranslationName()
@@ -71,7 +79,7 @@ QString Translator::findLangDir()
     QStorageInfo storage(qApp->applicationDirPath());
     QString rootPath = storage.rootPath();
 
-#ifdef Q_OS_LINUX
+#if defined(Q_OS_LINUX)
     QStringList langDirs;
 
     langDirs.append(QString("%1/usr/share/converseen/loc").arg(rootPath));
@@ -83,7 +91,8 @@ QString Translator::findLangDir()
         if (qmFilesFound(langDir))
             return langDir;
     }
-
+#elif defined(Q_OS_MACOS)
+    langDir = QString("%1/../Resources/loc").arg(binDir);
 #else
     langDir = QString("%1/loc").arg(binDir);
 #endif
